/**
 * Copyright (c) 2001-2022 by PDFTron Systems Inc. All Rights Reserved.
 * Consult legal.txt regarding legal and license information.
 */
#ifndef   H_PAGEMASTERAPI
#define   H_PAGEMASTERAPI

/** 
 * The calling convention to use for all calls across the "library boundary."
 */
#ifdef _WIN32
  #define PAGEMASTER_API_CALL __stdcall
	#ifdef PAGEMASTER_API_EXPORT
		#define PAGEMASTER_API(type) __declspec(dllexport) type PAGEMASTER_API_CALL 
	#else
		#define PAGEMASTER_API(type) __declspec(dllimport) type PAGEMASTER_API_CALL 
	#endif
#else
  #define PAGEMASTER_API_CALL
 	#ifdef PAGEMASTER_API_EXPORT
		#define PAGEMASTER_API(type) __attribute__ ((visibility("default"))) type PAGEMASTER_API_CALL 
	#else
		#define PAGEMASTER_API(type) type PAGEMASTER_API_CALL 
	#endif
#endif

#ifdef __cplusplus
extern "C" {
#endif

/** 
 * 'mode' identifier passed in PageMasterCallback.
 * The 'mode' can be used to determine whether a message is an error or 
 * a progress message.
 */ 
#define PAGEMASTER_ERROR    1  /* Show the error message  */
#define PAGEMASTER_MSG      2  /* Report the message      */
#define PAGEMASTER_GETPASS  3  /* Get the password        */
#define PAGEMASTER_OUT_FILENAME 4 /* Reports the Saved File Names */


typedef char* PAGEMASTER_API_CALL PageMasterCallback(int mode, char* msg, void* user_data);

/**
 * Initialize PageMaster with registration and license information.
 * Although PageMasterInit is typically called only once (e.g. during the program 
 * startup), it can also be called multiple times without side effects. 
 *
 * The first parameter is your username, the second parameter is your company name, 
 * and the last parameter is the license key supplied with your registration information.
 */
PAGEMASTER_API(int)
PageMasterInit(char* user_name, char* company, char* license_key);

/** 
 * Return codes for PageMasterRun function.
 */ 
#define PAGEMASTER_OK				0 /* No errors */
#define PAGEMASTER_ERR				1 /* Unspecified error */
#define PAGEMASTER_ERR_BADKEY		2 /* Bad license key */
#define PAGEMASTER_ERR_DIRCREATE	3 /* Failed to create the output directory */	
#define PAGEMASTER_ERR_BADFILENAME	4 /* Bad input filename or path */
#define PAGEMASTER_ERR_NOOUTFILE	5 /* Output file not specified */
#define PAGEMASTER_ERR_READINGPDF	6 /* error reading the input document */
#define PAGEMASTER_ERR_PASSWORD		7 /* document is secured. bad password. */
#define PAGEMASTER_ERR_WRITE		8 /* error writing an output file or folder */
#define PAGEMASTER_ERR_NOINPUTFILES 9 /* no input files found */

/**
 * Execute PageMaster command string.
 * 
 * PageMasterRun can be called multiple times to process PDF documents or folders 
 * with PDF documents. The function is completely thread safe, so it is possible to 
 * run many PageMaster threads at the same time.
 * 
 * @param command_str PageMaster command string. For a detailed explanation of 
 * all options and syntax, please refer to section 4 in PageMaster SDK Manual. 
 *
 * @param funct (optional) a pointer to the callback function used to report error 
 * as well as other messages. 
 *
 * @param user_data (optional) a pointer to custom data that you may want to 
 * pass to the callback function. NULL if you don't need to pass custom data.
 *
 * @return error code. A non-zero value indicates that an error was encountered.
 */
PAGEMASTER_API(int)
PageMasterRun(char* command_str, PageMasterCallback* funct, void* user_data);

#ifdef __cplusplus
}
#endif

#endif  /* H_PAGEMASTERAPI */
